Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Delete ¶
Delete a value on a specified path in the provided map[string]any or []any and get the updated object.
Types ¶
type Container ¶ added in v1.1.0
type Container struct {
Data any
}
Container stores data and updates it only if change operations have been performed successfully.
type InvalidPathError ¶ added in v1.1.0
func (*InvalidPathError) Error ¶ added in v1.1.0
func (e *InvalidPathError) Error() string
type NotFoundError ¶ added in v1.1.0
func (*NotFoundError) Error ¶ added in v1.1.0
func (e *NotFoundError) Error() string
Click to show internal directories.
Click to hide internal directories.